==> knative-model-6.0.0-sources.jar: io/fabric8/knative/eventing/v1/BrokerSpecFluentImpl.java <==
package io.fabric8.knative.eventing.v1;

import java.lang.SuppressWarnings;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReference;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceFluentImpl;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BrokerSpecFluentImpl<A extends BrokerSpecFluent<A>> extends BaseFluent<A> implements BrokerSpecFluent<A>{
  public BrokerSpecFluentImpl() {
  }
  public BrokerSpecFluentImpl(BrokerSpec instance) {
    this.withConfig(instance.getConfig()); 
    this.withDelivery(instance.getDelivery()); 
  }
  private KReferenceBuilder config;
  private DeliverySpecBuilder delivery;
  
  /**
   * This method has been deprecated, please use method buildConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public KReference getConfig() {
    return this.config!=null ?this.config.build():null;
  }
  public KReference buildConfig() {
    return this.config!=null ?this.config.build():null;
  }
  public A withConfig(KReference config) {
    _visitables.get("config").remove(this.config);
    if (config!=null){ this.config= new KReferenceBuilder(config); _visitables.get("config").add(this.config);} else { this.config = null; _visitables.get("config").remove(this.config); } return (A) this;
  }
  public Boolean hasConfig() {
    return this.config != null;
  }
  public A withNewConfig(String apiVersion,String kind,String name,String namespace) {
    return (A)withConfig(new KReference(apiVersion, kind, name, namespace));
  }
  public BrokerSpecFluent.ConfigNested<A> withNewConfig() {
    return new BrokerSpecFluentImpl.ConfigNestedImpl();
  }
  public BrokerSpecFluent.ConfigNested<A> withNewConfigLike(KReference item) {
    return new BrokerSpecFluentImpl.ConfigNestedImpl(item);
  }
  public BrokerSpecFluent.ConfigNested<A> editConfig() {
    return withNewConfigLike(getConfig());
  }
  public BrokerSpecFluent.ConfigNested<A> editOrNewConfig() {
    return withNewConfigLike(getConfig() != null ? getConfig(): new KReferenceBuilder().build());
  }
  public BrokerSpecFluent.ConfigNested<A> editOrNewConfigLike(KReference item) {
    return withNewConfigLike(getConfig() != null ? getConfig(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildDelivery instead.
   * @return The buildable object.
   */
  @Deprecated
  public DeliverySpec getDelivery() {
    return this.delivery!=null ?this.delivery.build():null;
  }
  public DeliverySpec buildDelivery() {
    return this.delivery!=null ?this.delivery.build():null;
  }
  public A withDelivery(DeliverySpec delivery) {
    _visitables.get("delivery").remove(this.delivery);
    if (delivery!=null){ this.delivery= new DeliverySpecBuilder(delivery); _visitables.get("delivery").add(this.delivery);} else { this.delivery = null; _visitables.get("delivery").remove(this.delivery); } return (A) this;
  }
  public Boolean hasDelivery() {
    return this.delivery != null;
  }
  public BrokerSpecFluent.DeliveryNested<A> withNewDelivery() {
    return new BrokerSpecFluentImpl.DeliveryNestedImpl();
  }
  public BrokerSpecFluent.DeliveryNested<A> withNewDeliveryLike(DeliverySpec item) {
    return new BrokerSpecFluentImpl.DeliveryNestedImpl(item);
  }
  public BrokerSpecFluent.DeliveryNested<A> editDelivery() {
    return withNewDeliveryLike(getDelivery());
  }
  public BrokerSpecFluent.DeliveryNested<A> editOrNewDelivery() {
    return withNewDeliveryLike(getDelivery() != null ? getDelivery(): new DeliverySpecBuilder().build());
  }
  public BrokerSpecFluent.DeliveryNested<A> editOrNewDeliveryLike(DeliverySpec item) {
    return withNewDeliveryLike(getDelivery() != null ? getDelivery(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BrokerSpecFluentImpl that = (BrokerSpecFluentImpl) o;
    if (config != null ? !config.equals(that.config) :that.config != null) return false;
    if (delivery != null ? !delivery.equals(that.delivery) :that.delivery != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(config,  delivery,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (config != null) { sb.append("config:"); sb.append(config + ","); }
    if (delivery != null) { sb.append("delivery:"); sb.append(delivery); }
    sb.append("}");
    return sb.toString();
  }
  class ConfigNestedImpl<N> extends KReferenceFluentImpl<BrokerSpecFluent.ConfigNested<N>> implements BrokerSpecFluent.ConfigNested<N>,Nested<N>{
    ConfigNestedImpl(KReference item) {
      this.builder = new KReferenceBuilder(this, item);
    }
    ConfigNestedImpl() {
      this.builder = new KReferenceBuilder(this);
    }
    KReferenceBuilder builder;
    public N and() {
      return (N) BrokerSpecFluentImpl.this.withConfig(builder.build());
    }
    public N endConfig() {
      return and();
    }
    
  }
  class DeliveryNestedImpl<N> extends DeliverySpecFluentImpl<BrokerSpecFluent.DeliveryNested<N>> implements BrokerSpecFluent.DeliveryNested<N>,Nested<N>{
    DeliveryNestedImpl(DeliverySpec item) {
      this.builder = new DeliverySpecBuilder(this, item);
    }
    DeliveryNestedImpl() {
      this.builder = new DeliverySpecBuilder(this);
    }
    DeliverySpecBuilder builder;
    public N and() {
      return (N) BrokerSpecFluentImpl.this.withDelivery(builder.build());
    }
    public N endDelivery() {
      return and();
    }
    
  }
  
}

==> knative-model-6.4.0-sources.jar: io/fabric8/knative/eventing/v1/BrokerSpecFluentImpl.java <==
package io.fabric8.knative.eventing.v1;

import java.lang.SuppressWarnings;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReference;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceFluentImpl;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BrokerSpecFluentImpl<A extends BrokerSpecFluent<A>> extends BaseFluent<A> implements BrokerSpecFluent<A>{
  public BrokerSpecFluentImpl() {
  }
  public BrokerSpecFluentImpl(BrokerSpec instance) {
    this.withConfig(instance.getConfig()); 
    this.withDelivery(instance.getDelivery()); 
  }
  private KReferenceBuilder config;
  private DeliverySpecBuilder delivery;
  
  /**
   * This method has been deprecated, please use method buildConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public KReference getConfig() {
    return this.config!=null ?this.config.build():null;
  }
  public KReference buildConfig() {
    return this.config!=null ?this.config.build():null;
  }
  public A withConfig(KReference config) {
    _visitables.get("config").remove(this.config);
    if (config!=null){ this.config= new KReferenceBuilder(config); _visitables.get("config").add(this.config);} else { this.config = null; _visitables.get("config").remove(this.config); } return (A) this;
  }
  public Boolean hasConfig() {
    return this.config != null;
  }
  public A withNewConfig(String apiVersion,String group,String kind,String name,String namespace) {
    return (A)withConfig(new KReference(apiVersion, group, kind, name, namespace));
  }
  public BrokerSpecFluent.ConfigNested<A> withNewConfig() {
    return new BrokerSpecFluentImpl.ConfigNestedImpl();
  }
  public BrokerSpecFluent.ConfigNested<A> withNewConfigLike(KReference item) {
    return new BrokerSpecFluentImpl.ConfigNestedImpl(item);
  }
  public BrokerSpecFluent.ConfigNested<A> editConfig() {
    return withNewConfigLike(getConfig());
  }
  public BrokerSpecFluent.ConfigNested<A> editOrNewConfig() {
    return withNewConfigLike(getConfig() != null ? getConfig(): new KReferenceBuilder().build());
  }
  public BrokerSpecFluent.ConfigNested<A> editOrNewConfigLike(KReference item) {
    return withNewConfigLike(getConfig() != null ? getConfig(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildDelivery instead.
   * @return The buildable object.
   */
  @Deprecated
  public DeliverySpec getDelivery() {
    return this.delivery!=null ?this.delivery.build():null;
  }
  public DeliverySpec buildDelivery() {
    return this.delivery!=null ?this.delivery.build():null;
  }
  public A withDelivery(DeliverySpec delivery) {
    _visitables.get("delivery").remove(this.delivery);
    if (delivery!=null){ this.delivery= new DeliverySpecBuilder(delivery); _visitables.get("delivery").add(this.delivery);} else { this.delivery = null; _visitables.get("delivery").remove(this.delivery); } return (A) this;
  }
  public Boolean hasDelivery() {
    return this.delivery != null;
  }
  public BrokerSpecFluent.DeliveryNested<A> withNewDelivery() {
    return new BrokerSpecFluentImpl.DeliveryNestedImpl();
  }
  public BrokerSpecFluent.DeliveryNested<A> withNewDeliveryLike(DeliverySpec item) {
    return new BrokerSpecFluentImpl.DeliveryNestedImpl(item);
  }
  public BrokerSpecFluent.DeliveryNested<A> editDelivery() {
    return withNewDeliveryLike(getDelivery());
  }
  public BrokerSpecFluent.DeliveryNested<A> editOrNewDelivery() {
    return withNewDeliveryLike(getDelivery() != null ? getDelivery(): new DeliverySpecBuilder().build());
  }
  public BrokerSpecFluent.DeliveryNested<A> editOrNewDeliveryLike(DeliverySpec item) {
    return withNewDeliveryLike(getDelivery() != null ? getDelivery(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BrokerSpecFluentImpl that = (BrokerSpecFluentImpl) o;
    if (config != null ? !config.equals(that.config) :that.config != null) return false;
    if (delivery != null ? !delivery.equals(that.delivery) :that.delivery != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(config,  delivery,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (config != null) { sb.append("config:"); sb.append(config + ","); }
    if (delivery != null) { sb.append("delivery:"); sb.append(delivery); }
    sb.append("}");
    return sb.toString();
  }
  class ConfigNestedImpl<N> extends KReferenceFluentImpl<BrokerSpecFluent.ConfigNested<N>> implements BrokerSpecFluent.ConfigNested<N>,Nested<N>{
    ConfigNestedImpl(KReference item) {
      this.builder = new KReferenceBuilder(this, item);
    }
    ConfigNestedImpl() {
      this.builder = new KReferenceBuilder(this);
    }
    KReferenceBuilder builder;
    public N and() {
      return (N) BrokerSpecFluentImpl.this.withConfig(builder.build());
    }
    public N endConfig() {
      return and();
    }
    
  }
  class DeliveryNestedImpl<N> extends DeliverySpecFluentImpl<BrokerSpecFluent.DeliveryNested<N>> implements BrokerSpecFluent.DeliveryNested<N>,Nested<N>{
    DeliveryNestedImpl(DeliverySpec item) {
      this.builder = new DeliverySpecBuilder(this, item);
    }
    DeliveryNestedImpl() {
      this.builder = new DeliverySpecBuilder(this);
    }
    DeliverySpecBuilder builder;
    public N and() {
      return (N) BrokerSpecFluentImpl.this.withDelivery(builder.build());
    }
    public N endDelivery() {
      return and();
    }
    
  }
  
}
